@@ -112,7 +112,7 @@ class FEniCSDiffusion1D(BayesianProblem):
         
         # Set up exact solution
         if exactSolution is None:
-            exactSolution = prior.sample()
+            exactSolution = x.sample()
         elif exactSolution == 'smooth_step':
             N = dim + 1
             fun = lambda grid:  0.8*np.exp( -( (grid -endpoint/2.0 )**2 ) / 0.02)
@@ -136,8 +136,8 @@ class FEniCSDiffusion1D(BayesianProblem):
             b_exact + alpha*noise, geometry=range_geometry)
 
         # Create likelihood
-        y = cuqi.distribution.GaussianCov(
-            model(x), alpha*np.eye(range_geometry.par_dim))
+        y = cuqi.distribution.Gaussian(
+            mean=model(x), cov=alpha*np.eye(range_geometry.par_dim))
 
         # Initialize FEniCSDiffusion1D as BayesianProblem problem
         super().__init__(y, x, y=data)
